crabnet.data package
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   crabnet.data.benchmark_data
   crabnet.data.element_properties
   crabnet.data.matbench
   crabnet.data.materials_data

Submodules
----------

crabnet.data.get\_dataset\_size module
--------------------------------------

.. automodule:: crabnet.data.get_dataset_size
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: crabnet.data
   :members:
   :undoc-members:
   :show-inheritance:
